@@ -20,7 +20,8 @@ Search through the project for method declarations, invocants or free
 text using Ack.
 
 Run tests and scripts with easy navigation to errors/warnings/failing
-tests.
+tests. Tests can be run under Devel::Cover to collect (and display)
+test coverage information.
 
 Automate common editing tasks related to source code, tests, regular
 expressions, etc.
@@ -108,6 +109,9 @@ Compilation mode and the settings appropriate for the source type
 (Test, Module, etc.). Highlight errors and jump to source with C-c
 C-c.
 
+B<Run file under Devel::CoverX::Covered> -- C<C-o r c> -- Run the
+current file, collecting Devel::CoverX::Covered information.
+
 B<Edit - Copy Package Name> -- C<C-o e c p> -- Copy the current package name.
 
 B<Edit - Add Use Statement> -- C<C-o e a u> -- Add a 'use Module'
@@ -238,7 +242,8 @@ These aren't needed to begin with, but may be very useful.
 =item * L<Devel::CoverX::Covered>
 
 If you have a lot of tests to navigate and run a nightly build with
-Devel::Cover to generate test coverage.
+Devel::Cover to generate test coverage. You can also run individual
+files under Devel::CoverX::Covered with C<C-o r c>.
 
 =item * L<File::Corresponding>
 
@@ -838,6 +843,15 @@ Note: this will re-run whatever is displayed in the B<*compilation*>
 buffer.
 
 
+=head3 Run File under Devel::CoverX::Covered
+
+C<C-o r c> -- This is the same as Run File, but collect test coverage
+information using Devel::CoverX::Covered.
+
+Note: Currently this only works with Unix like shells.
+
+
+
 =head3 Go to Run-buffer
 
 Invoke C<C-o g r> to go to the B<*compilation*> buffer.
@@ -901,6 +915,9 @@ limited to those that cover that particular sub.
 This requires that L<Devel::CoverX::Covered> is installed and a
 L<Devel::Cover> cover_db in the project root directory.
 
+You can build the coverage database either as a (very slow) separate
+test run, or by running individual files with C<C-o r c>.
+
 See L<Devel::CoverX::Covered> for details.
 
 
@@ -1126,6 +1143,16 @@ ordinarily the case).
 Note: Running the test suite with Devel::Cover can be very, very
 slow. A nightly build is usually a good idea.
 
+You can also collect / undate coverage information for indivual test
+files with C<C-o r c>. This is the easiest way to just try it out.
+
+You might want to add the following to be ignored by your VCS
+(e.g. .gitignore):
+
+    /cover_db/*
+    /covered/*
+
+
 
 =head3 Using Coverage Visualization
 
@@ -1684,7 +1711,7 @@ L<http://vimdoc.sourceforge.net/htmldoc/eval.html#Dictionaries> - Vim native dat
 
 =head1 AUTHOR
 
-Johan Lindstrm, C<< <johanl buzzwordninja.com> >>
+Johan Lindstrom, C<< <johanl buzzwordninja.com> >>
 
 =head1 CONTRIBUTIONS, BUGS, AND CAVEATS
 
@@ -1736,7 +1763,7 @@ Jaeyoun Chung for dropdown-list L<http://www.emacswiki.org/cgi-bin/wiki/dropdown
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2007 Johan Lindstrm, All Rights Reserved.
+Copyright 2007 Johan Lindstrom, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
@@ -1752,10 +1779,7 @@ use warnings;
 use utf8;
 
 package Devel::PerlySense;
-{
-  $Devel::PerlySense::VERSION = '0.0211';
-}
-
+$Devel::PerlySense::VERSION = '0.0212';
 
 
 use Spiffy -Base;
