@@ -17,10 +17,7 @@ use warnings;
 use utf8;
 
 package Devel::PerlySense::Bookmark::MatchResult;
-{
-  $Devel::PerlySense::Bookmark::MatchResult::VERSION = '0.0211';
-}
-
+$Devel::PerlySense::Bookmark::MatchResult::VERSION = '0.0212';
 
 
 
@@ -172,7 +169,7 @@ __END__
 
 =head1 AUTHOR
 
-Johan Lindstrm, C<< <johanl[T]DarSerMan.com> >>
+Johan Lindstrom, C<< <johanl@cpan.org> >>
 
 =head1 BUGS
 
@@ -186,7 +183,7 @@ your bug as I make changes.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2005 Johan Lindstrm, All Rights Reserved.
+Copyright 2005 Johan Lindstrom, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
