@@ -33,10 +33,7 @@ use warnings;
 use utf8;
 
 package Devel::PerlySense::Document;
-{
-  $Devel::PerlySense::Document::VERSION = '0.0211';
-}
-
+$Devel::PerlySense::Document::VERSION = '0.0212';
 
 
 
@@ -791,7 +788,7 @@ sub determineLikelyApi {
         $self->rhPackageApiLikely($rhPackageApi);
     } else {
         $self->determineLikelyApi0(nameModule => $nameModule);
-       $self->cacheSet($keyCache, $self->file, $self->rhPackageApiLikely);
+        $self->cacheSet($keyCache, $self->file, $self->rhPackageApiLikely);
    }
 
     return(1);
@@ -1176,7 +1173,7 @@ __END__
 
 =head1 AUTHOR
 
-Johan Lindstrm, C<< <johanl[T]DarSerMan.com> >>
+Johan Lindstrom, C<< <johanl@cpan.org> >>
 
 =head1 BUGS
 
@@ -1190,7 +1187,7 @@ your bug as I make changes.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2005 Johan Lindstrm, All Rights Reserved.
+Copyright 2005 Johan Lindstrom, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
