@@ -16,10 +16,7 @@ use warnings;
 use utf8;
 
 package Devel::PerlySense::Editor;
-{
-  $Devel::PerlySense::Editor::VERSION = '0.0211';
-}
-
+$Devel::PerlySense::Editor::VERSION = '0.0212';
 
 
 
@@ -651,7 +648,7 @@ __END__
 
 =head1 AUTHOR
 
-Johan Lindstrm, C<< <johanl[T]DarSerMan.com> >>
+Johan Lindstrom, C<< <johanl@cpan.org> >>
 
 =head1 BUGS
 
@@ -665,7 +662,7 @@ your bug as I make changes.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2005 Johan Lindstrm, All Rights Reserved.
+Copyright 2005 Johan Lindstrom, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
