@@ -24,10 +24,7 @@ use warnings;
 use utf8;
 
 package Devel::PerlySense::Project;
-{
-  $Devel::PerlySense::Project::VERSION = '0.0211';
-}
-
+$Devel::PerlySense::Project::VERSION = '0.0212';
 
 
 use Spiffy -Base;
@@ -725,7 +722,7 @@ __END__
 
 =head1 AUTHOR
 
-Johan Lindstrm, C<< <johanl[T]DarSerMan.com> >>
+Johan Lindstrom, C<< <johanl@cpan.org> >>
 
 =head1 BUGS
 
@@ -739,7 +736,7 @@ your bug as I make changes.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2005 Johan Lindstrm, All Rights Reserved.
+Copyright 2005 Johan Lindstrom, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
