@@ -11,9 +11,7 @@ use warnings;
 use utf8;
 
 package Devel::PerlySense::Util;
-{
-  $Devel::PerlySense::Util::VERSION = '0.0211';
-}
+$Devel::PerlySense::Util::VERSION = '0.0212';
 use base "Exporter";
 
 our @EXPORT = (
@@ -169,7 +167,7 @@ __END__
 
 =head1 AUTHOR
 
-Johan Lindstrm, C<< <johanl[T]DarSerMan.com> >>
+Johan Lindstrom, C<< <johanl@cpan.org> >>
 
 =head1 BUGS
 
@@ -183,7 +181,7 @@ your bug as I make changes.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2005 Johan Lindstrm, All Rights Reserved.
+Copyright 2005 Johan Lindstrom, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
